Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
QUOT(8) 		     System Manager's Manual			 QUOT(8)

NAME
     quot -- display disk space occupied by each user

SYNOPSIS
     quot [-cfknv] [-a | filesystem ...]

DESCRIPTION
     The  quot	utility  is  used  to gather per-user disk usage statistics from
     ffs(7) file systems.

     The following options are available:

     -a      Include statistics for all mounted file systems.

     -c      Display three columns containing number of blocks per file,  number
	     of  files	in this category, and aggregate total of blocks in files
	     with this or lower size.  This option is  mutually  exclusive  with
	     the -n option.

     -f      For each user, display count of files and space occupied.	This op-
	     tion has no effect if combined with the -c or -n options.

     -k      Force  the  numbers to be reported in kilobyte counts.  By default,
	     all sizes are reported in 512-byte block counts.

     -n      Given a list of inodes (plus some optional data on  each  line)  in
	     the standard input, for each file print out the owner (plus the re-
	     mainder  of the input line).  Lines that do not begin with a number
	     are ignored.  This is traditionally used in the pipe:

		   ls -i | sed -e 's,^	*,,' | sort -k 1n | quot -n filesystem

	     to get a report of files and their owners.  This option is mutually
	     exclusive with the -c option.

     -v      In addition to the default output, display the number of files  not
	     accessed  within  30, 60 and 90 days.  This option has no effect if
	     combined with the -c or -n options.

ENVIRONMENT
     BLOCKSIZE	If the environment variable BLOCKSIZE is set, and the -k  option
		is not specified, the block counts will be displayed in units of
		that size block.

SEE ALSO
     df(1), quota(1), getmntinfo(3), fstab(5), ffs(7), mount(8)

HISTORY
     This implementation of quot is by Wolfgang Solfrank / TooLs GmbH.

BUGS
     ncheck  (which  would be a lot more useful than ls -i in the example above)
     does not exist in FreeBSD.

FreeBSD 15.1			November 13, 2025			 QUOT(8)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=quot&sektion=8&manpath=FreeBSD+15.1-RELEASE+and+Ports>

home | help